@@ -1,7 +1,7 @@
 """
 Type annotations for shield service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/literals.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_shield/literals/)
 
 Usage::
 
@@ -33,7 +33,9 @@ __all__ = (
     "SubResourceTypeType",
     "SubscriptionStateType",
     "UnitType",
+    "ShieldServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -67,6 +69,7 @@ ProtectionGroupPatternType = Literal["ALL", "ARBITRARY", "BY_RESOURCE_TYPE"]
 SubResourceTypeType = Literal["IP", "URL"]
 SubscriptionStateType = Literal["ACTIVE", "INACTIVE"]
 UnitType = Literal["BITS", "BYTES", "PACKETS", "REQUESTS"]
+ShieldServiceName = Literal["shield"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -98,6 +101,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -184,6 +188,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -220,6 +225,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -284,6 +290,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
@@ -368,4 +375,16 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["list_attacks", "list_protections"]
